@@ -23,7 +23,7 @@ def resources(format) -> None:
     default = Config.instance().get("default_resource")
     for (slug, profile) in get_profiles().items():
         if format == "simple":
-            click.echo(slug)
+            click.echo("\n".join([slug, *profile.aliases]))
         else:
             star = "* " if default == slug else ""
             aliases = f" [{', '.join(profile.aliases)}]" if profile.aliases else ""
