@@ -18,4 +18,4 @@ class GlobalOptionsBase:
             if kwargs:
                 message += ": " + ",".join([f"{k}={v}" for k, v in kwargs.items()])
             mod = inspect.getmodule(inspect.stack()[1][0])
-            logging.getLogger(mod.__name__).debug(message)
+            logging.getLogger(mod.__name__ if mod else __name__).info(message)
