@@ -22,16 +22,21 @@ from ..errors import (
     SuppressedError,
     TargetNotConnected,
     WrappedSubprocessError,
+    raise_if_match,
+)
+from ..helpers.boto import (
+    AccessDeniedPattern,
+    TargetNotConnectedPattern,
+    send_ssh_key,
+    ssm_interactive_command,
+    ssm_ssh_session,
 )
-from ..helpers.boto import send_ssh_key, ssm_interactive_command, ssm_ssh_session
 from ..helpers.config import Config, SymConfigFile
 from ..helpers.params import get_ssh_user
 from ..helpers.sym_group import SymGroup
 from ..saml_clients.saml_client import SAMLClient
 
 MissingPublicKeyPattern = re.compile(r"Permission denied \(.*publickey.*\)")
-TargetNotConnectedPattern = re.compile("TargetNotConnected")
-AccessDeniedPattern = re.compile("AccessDeniedException")
 ConnectionClosedPattern = re.compile(r"Connection to .* closed")
 
 SSHConfigPath = "ssh/config"
@@ -200,18 +205,22 @@ def start_ssh_session(
         _on_ssh_error(client, instance, args=args)
         if MissingPublicKeyPattern.search(err.stderr):
             raise MissingPublicKey(err, get_ssh_user()) from err
+
         # If the ssh key path is cached then this doesn't get intercepted in ensure_ssh_key
-        elif TargetNotConnectedPattern.search(err.stderr):
-            raise TargetNotConnected() from err
-        elif AccessDeniedPattern.search(err.stderr):
-            raise AccessDenied() from err
+        raise_if_match(
+            {
+                TargetNotConnectedPattern: TargetNotConnected,
+                AccessDeniedPattern: AccessDenied,
+            },
+            err.stderr,
+        )
+
+        if wrap:
+            raise WrappedSubprocessError(
+                err, f"Contact your Sym administrator.", report=True
+            ) from err
         else:
-            if wrap:
-                raise WrappedSubprocessError(
-                    err, f"Contact your Sym administrator.", report=True
-                ) from err
-            else:
-                raise SuppressedError(err, echo=True)
+            raise SuppressedError(err, echo=True)
     else:
         Config.touch_instance(instance)
 
