@@ -28,7 +28,7 @@ class SymUpdater:
     def __init__(self, debug: bool = False):
         cli_name = Config.get_cli_name()
         self.module = importlib.import_module(cli_name.replace("-", "."))
-        self.dir = Path(inspect.getfile(self.module)).parent
+        self.dir = Path(inspect.getfile(self.module)).resolve().parent
         for _ in range(len(cli_name.split("-"))):
             self.dir = self.dir.parent
         self.latest_version: Optional[VersionInfo] = None
