@@ -1,10 +1,18 @@
 import importlib
+import os
 import pkgutil
 import sys
 from functools import reduce, wraps
-from pathlib import Path
 from typing import Any, List
 
+from click import Command, Parameter
+
+from sym.cli.helpers.updater import SymUpdater
+
+
+def is_prod_mode():
+    return not SymUpdater().is_local()
+
 
 def import_all(name):
     for _, module_name, _ in pkgutil.walk_packages(sys.modules[name].__path__):
@@ -39,3 +47,7 @@ def wrap(val):
 
 def flow(fns: List, val: Any):
     return reduce(lambda f, x: x(f), fns, val)
+
+
+def get_param(command: Command, name: str) -> Parameter:
+    return next(p for p in command.params if p.name == name)
