@@ -1,6 +1,7 @@
 import tempfile
 from contextlib import contextmanager
 from pathlib import Path
+from textwrap import dedent
 from typing import Callable, ContextManager, Iterator, Tuple, Type, TypeVar
 
 import click
@@ -21,6 +22,19 @@ P = TypeVar("P", bound=SAMLClient)
 TestContextFixture = Callable[..., ContextManager[P]]
 
 
+@pytest.fixture
+def config_with_duplicate_sections() -> str:
+    return dedent(
+        """
+        [custom]
+        app_id  = xxx
+        [custom]
+        app_id  = abc
+        username = u123
+        """
+    )
+
+
 @pytest.fixture
 def test_context(
     constructor: Type[P],
